# What's Changed

1. ✨ 新增: add English README by @CAICAIIs
2. ✨ 新增: perf: 优化网页录音 [#283](https://github.com/Soulter/AstrBot/issues/283) by @Fridemn
3. ✨ 新增: 添加对于 Edge-TTS 的支持 [#471](https://github.com/Soulter/AstrBot/issues/471) by @Fridemn
4. ⚡ 优化: 为防止输入一大堆 k，改 k 键为 Ctrl 键；改为长按录音，松手结束；为防止误触改为只有点击输入框之后才会生效 by @Fridemn
5. ⚡ 优化: 插件市场非列表视图能够正常搜索 [#640](https://github.com/Soulter/AstrBot/issues/640) by @Fridemn
6. ⚡ 优化: 插件市场帮助按钮 tooltip 移入时会消失无法点击其中链接，更改为按钮触发 by @Quirrel-zh
7. ‼️‼️ 🐛 修复: v3.4.32 无法记忆历史的会话 [#630](https://github.com/Soulter/AstrBot/issues/630)
8. ‼️🐛 修复: 钩子函数无法终止事件传播的问题；修复某些情况下终止事件传播后仍然会请求 LLM 的问题
9. ‼️🐛 修复: OneBot V11 通知类事件某些情况无法回复问题 by @CAICAIIs
10. 🐛 修复: Correct STT model path and improve logging in provider manager and pip installer
11. 🐛 修复: 由于已安装插件与插件市场中 name 不一致或 repo 链接大小写不一致导致的检测不到是否安装或有更新 by @Quirrel-zh